netapp_ontap.resources.volume_efficiency_policy API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.volume_efficiency_policy`

Copyright © 2020 NetApp Inc. All rights reserved.

### Overview

Volume efficiency policies specify information about efficiency policies that are applied to the volume.

## Volume efficiency policy APIs

The following APIs are used to perform operations related to volume efficiency policy information:

- POST /api/storage/volume-efficiency-policies
- GET /api/storage/volume-efficiency-policies
- GET /api/storage/volume-efficiency-policies/{uuid}
- PATCH /api/storage/volume-efficiency-policies/{uuid}
- DELETE /api/storage/volume-efficiency-policies/{uuid}

## Examples

### Creating a volume efficiency policy

The POST operation is used to create a volume efficiency policy with the specified attributes.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import VolumeEfficiencyPolicy

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = VolumeEfficiencyPolicy()
        resource.name = "new_policy"
        resource.type = "scheduled"
        resource.schedule.name = "daily"
        resource.duration = "2"
        resource.qos_policy = "best_effort"
        resource.enabled = True
        resource.comment = "schedule-policy"
        resource.svm.name = "vs1"
        resource.post(hydrate=True)
        print(resource)

Try it out

    VolumeEfficiencyPolicy(
        {
            "duration": 2,
            "svm": {"name": "vs1"},
            "type": "scheduled",
            "schedule": {"name": "daily"},
            "enabled": True,
            "qos_policy": "best_effort",
            "name": "new_policy",
            "comment": "schedule-policy",
            "uuid": "a69d8173-450c-11e9-aa44-005056bbc848",
        }
    )

### Retrieving volume efficiency policy attributes

The GET operation is used to retrieve volume efficiency policy attributes.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import VolumeEfficiencyPolicy

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(VolumeEfficiencyPolicy.get_collection()))

Try it out

    [
        VolumeEfficiencyPolicy(
            {
                "_links": {
                    "self": {
                        "href": "/api/storage/volume-efficiency-policies/3c112527-2fe8-11e9-b55e-005056bbf1c8"
                    }
                },
                "name": "default",
                "uuid": "3c112527-2fe8-11e9-b55e-005056bbf1c8",
            }
        ),
        VolumeEfficiencyPolicy(
            {
                "_links": {
                    "self": {
                        "href": "/api/storage/volume-efficiency-policies/3c1c1656-2fe8-11e9-b55e-005056bbf1c8"
                    }
                },
                "name": "default-1weekly",
                "uuid": "3c1c1656-2fe8-11e9-b55e-005056bbf1c8",
            }
        ),
        VolumeEfficiencyPolicy(
            {
                "_links": {
                    "self": {
                        "href": "/api/storage/volume-efficiency-policies/3c228b82-2fe8-11e9-b55e-005056bbf1c8"
                    }
                },
                "name": "none",
                "uuid": "3c228b82-2fe8-11e9-b55e-005056bbf1c8",
            }
        ),
    ]

### Retrieving the attributes of a specific volume efficiency policy

The GET operation is used to retrieve the attributes of a specific volume efficiency policy.

# The API:

/api/storage/volume-efficiency-policies/{uuid}

# The call:

curl -X GET "https:///api/storage/volume-efficiency-policies/3c112527-2fe8-11e9-b55e-005056bbf1c8" -H "accept: application/hal+json"

# The response:

HTTP/1.1 200 OK Date: Tue, 12 Mar 2019 21:24:48 GMT Server: libzapid-httpd X-Content-Type-Options: nosniff Cache-Control: no-cache,no-store,must-revalidate Content-Length: 381 Content-Type: application/json { "uuid": "3c112527-2fe8-11e9-b55e-005056bbf1c8", "name": "new_policy", "type": "scheduled", "schedule": { "name": "daily" } "duration": "2", "qos_policy": "best_effort", "enabled": "true", "comment": "schedule-policy", "svm": { "name": "vs1" } "_links": { "self": { "href": "/api/storage/volume-efficiency-policies/3c112527-2fe8-11e9-b55e-005056bbf1c8" } } }

    ### Updating a volume efficiency policy
    The PATCH operation is used to update the specific attributes of a volume efficiency policy.
    ```python
    from netapp_ontap import HostConnection
    from netapp_ontap.resources import VolumeEfficiencyPolicy

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = VolumeEfficiencyPolicy(uuid="ae9e65c4-4506-11e9-aa44-005056bbc848")
        resource.duration = "3"
        resource.patch()

### Deleting a volume efficiency policy

The DELETE operation is used to delete a volume efficiency policy.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import VolumeEfficiencyPolicy

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = VolumeEfficiencyPolicy(uuid="ae9e65c4-4506-11e9-aa44-005056bbc848")
        resource.delete()

## Classes

`class VolumeEfficiencyPolicy (*args, **kwargs)`

  Allows interaction with VolumeEfficiencyPolicy objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves a collection of volume efficiency policies.

    ### Related ONTAP commands

    - `volume efficiency policy show`

    ### Learn more

    - `DOC /storage/volume-efficiency-policies`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection(*args, body: typing.Union = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes a volume efficiency policy.

    ### Related ONTAP commands

    - `volume efficiency policy modify`

    ### Learn more

    - `DOC /storage/volume-efficiency-policies`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves a collection of volume efficiency policies.

    ### Related ONTAP commands

    - `volume efficiency policy show`

    ### Learn more

    - `DOC /storage/volume-efficiency-policies`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves a collection of volume efficiency policies.

    ### Related ONTAP commands

    - `volume efficiency policy show`

    ### Learn more

    - `DOC /storage/volume-efficiency-policies`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection(body: dict, *args, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates a volume efficiency policy.

    ### Related ONTAP commands

    - `volume efficiency policy modify`

    ### Learn more

    - `DOC /storage/volume-efficiency-policies`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Deletes a volume efficiency policy.

    ### Related ONTAP commands

    - `volume efficiency policy modify`

    ### Learn more

    - `DOC /storage/volume-efficiency-policies`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves the details of the specified volume efficiency policy.

    ### Related ONTAP commands

    - `volume efficiency policy show`

    ### Learn more

    - `DOC /storage/volume-efficiency-policies`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Updates a volume efficiency policy.

    ### Related ONTAP commands

    - `volume efficiency policy modify`

    ### Learn more

    - `DOC /storage/volume-efficiency-policies`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Creates a volume efficiency policy.

    ### Required properties

    - `svm.uuid` or `svm.name` - Existing SVM in which to create the volume efficiency policy.
    - `name` - Name for the volume efficiency policy.

    ### Recommended optional properties

    - `type` - Type of volume policy.
    - `schedule` - Schedule the volume efficiency defined in minutes, hourly, daily and weekly.
    - `duration` - Indicates the allowed duration for a session for policy type "threshold" and "auto".
    - `start_threshold_percent` - Indicates the start threshold percentage for the policy type "threshold". It is mutually exclusive of the schedule.
    - `qos_policy` - QoS policy for the sis operation.
    - `comment` - A comment associated with the volume efficiency policy.
    - `enabled` - Is the volume efficiency policy enabled?

    ### Default property values

    If not specified in POST, the following default property values are assigned: * `type` - auto * `enabled` - true * `qos_policy` - best_effort

    ### Related ONTAP commands

    - `volume efficiency policy create`

    ### Learn more

    - `DOC /storage/volume-efficiency-policies`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class VolumeEfficiencyPolicySchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the VolumeEfficiencyPolicy object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `comment GET POST PATCH`

    A comment associated with the volume efficiency policy.

  `duration GET POST PATCH`

    This field is used with the policy types "scheduled" and "auto" to indicate the allowed duration for a session, in hours. Possible value is a number between 0 and 999 inclusive. Default is unlimited indicated by value 0.

    Example: 5

  `enabled GET POST PATCH`

    Is the volume efficiency policy enabled?

    Example: true

  `links GET`

    The links field of the volume_efficiency_policy.

  `name GET POST`

    Name of the volume efficiency policy.

    Example: default

  `qos_policy GET POST PATCH`

    QoS policy for the sis operation. Possible values are background and best_effort. In background, sis operation will run in background with minimal or no impact on data serving client operations. In best_effort, sis operations may have some impact on data serving client operations.

    Valid choices:

    - background
    - best_effort
  `schedule GET POST PATCH`

    The schedule field of the volume_efficiency_policy.

  `start_threshold_percent GET POST PATCH`

    This field is used with the policy type "threshold" to indicate the threshold percentage for triggering the volume efficiency policy. It is mutuallly exclusive of the schedule.

    Example: 30

  `svm GET POST`

    The svm field of the volume_efficiency_policy.

  `type GET POST PATCH`

    Type of volume efficiency policy.

    Valid choices:

    - threshold
    - scheduled
    - auto
  `uuid GET`

    Unique identifier of volume efficiency policy.

    Example: 1cd8a442-86d1-11e0-ae1c-123478563412